@@ -86,7 +86,7 @@ timediff_now (struct timeval *target) {
 int
 delete_all_action (GPParams *p)
 {
-	return (gp_camera_folder_delete_all (p->camera, p->folder, p->context));
+	return gp_camera_folder_delete_all (p->camera, p->folder, p->context);
 }
 
 int
@@ -107,12 +107,12 @@ action_camera_upload_file (GPParams *p, const char *folder, const char *path)
 	if (p->filename && strcmp (p->filename, ""))
 		fn = p->filename;
 	else
-		fn = basename (path);
+		fn = basename ((char*)path);
 
 	res = gp_camera_folder_put_file (p->camera, folder, fn, GP_FILE_TYPE_NORMAL, file,
 					 p->context);
 	gp_file_unref (file);
-	return (res);
+	return res;
 }
 
 int
@@ -128,19 +128,19 @@ action_camera_upload_metadata (GPParams *p, const char *folder, const char *path
 	res = gp_file_open (file, path);
 	if (res < 0) {
 		gp_file_unref (file);
-		return (res);
+		return res;
 	}
 
 	/* Check if the user specified a filename */
 	if (p->filename && strcmp (p->filename, "")) {
 		fn = p->filename;
 	} else if (path == strstr(path, "meta_")) {
-		fn = path+5;
+		fn = (char*)(path+5);
 	}
 	res = gp_camera_folder_put_file (p->camera, folder, fn, GP_FILE_TYPE_METADATA, file,
 					 p->context);
 	gp_file_unref (file);
-	return (res);
+	return res;
 }
 
 int
@@ -180,7 +180,7 @@ num_files_action (GPParams *p)
 		printf (_("Number of files in folder '%s': %i\n"),
 			p->folder, filecount);
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -198,7 +198,7 @@ list_folders_action (GPParams *p)
 	CL (count = gp_list_count (list), list);
 	if (!(p->flags & FLAGS_QUIET))
 		printf(ngettext(
-			"There is %d folder in folder '%s'.\n", 
+			"There is %d folder in folder '%s'.\n",
 			"There are %d folders in folder '%s'.\n",
 			count
 		), count, p->folder);
@@ -214,7 +214,7 @@ list_folders_action (GPParams *p)
 			printf (" - %s\n", name);
 	}
 	gp_list_free (list);
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -261,7 +261,7 @@ list_files_action (GPParams *p)
 		CL (print_file_action (p, p->folder, name), list);
 	}
 	gp_list_free (list);
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -335,7 +335,7 @@ print_info_action (GPParams *p, const char *folder, const char *filename)
 				(info.audio.status == GP_FILE_STATUS_DOWNLOADED) ? _("yes") : _("no"));
 	}
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -351,77 +351,105 @@ print_file_action (GPParams *p, const char *folder, const char *filename)
 		if (info.file.fields & GP_FILE_INFO_STATUS &&
 		    info.file.status == GP_FILE_STATUS_DOWNLOADED) {
 			x++;
-			return (GP_OK);
+			return GP_OK;
 		}
 	}
 
 	if (p->flags & FLAGS_QUIET)
-		printf ("%s/%s\n", folder, filename);
+        if (p->flags & FLAGS_PARSABLE) {
+            CameraFileInfo info;
+
+            printf ("FILENAME='%s/%s'", folder, filename);
+            if (gp_camera_file_get_info (p->camera, folder, filename,
+                             &info, NULL) == GP_OK) {
+                if (info.file.fields & GP_FILE_INFO_PERMISSIONS) {
+                    printf(" PERMS=%s%s",
+                           (info.file.permissions & GP_FILE_PERM_READ) ? "r" : "-",
+                           (info.file.permissions & GP_FILE_PERM_DELETE) ? "d" : "-");
+                }
+                if (info.file.fields & GP_FILE_INFO_SIZE)
+                    printf(" FILESIZE=%5ld", (unsigned long int)info.file.size);
+                if ((info.file.fields & GP_FILE_INFO_WIDTH) && +
+                    (info.file.fields & GP_FILE_INFO_HEIGHT)) {
+                    printf(" IMGWIDTH=%d", info.file.width);
+                    printf(" IMGHEIGHT=%d", info.file.height);
+                }
+                if (info.file.fields & GP_FILE_INFO_TYPE)
+                    printf(" FILETYPE=%s", info.file.type);
+                if (info.file.fields & GP_FILE_INFO_MTIME)
+                    printf(" FILEMTIME=%ld", info.file.mtime);
+                printf("\n");
+            } else
+                printf ("FILENAME='%s/%s'\n", folder, filename);
+        } else
+            printf ("%s/%s\n", folder, filename);
 	else {
 		CameraFileInfo info;
 		if (gp_camera_file_get_info (p->camera, folder, filename,
 					     &info, NULL) == GP_OK) {
 		    printf("#%-5i %-27s", x+1, filename);
 		    if (info.file.fields & GP_FILE_INFO_PERMISSIONS) {
-			printf("%s%s",
-			       (info.file.permissions & GP_FILE_PERM_READ) ? "r" : "-",
-			       (info.file.permissions & GP_FILE_PERM_DELETE) ? "d" : "-");
+                printf("%s%s",
+                       (info.file.permissions & GP_FILE_PERM_READ) ? "r" : "-",
+                       (info.file.permissions & GP_FILE_PERM_DELETE) ? "d" : "-");
 		    }
 		    if (info.file.fields & GP_FILE_INFO_SIZE)
-			printf(" %5ld KB", (unsigned long int)((info.file.size+1023) / 1024));
+                printf(" %5ld KB", (unsigned long int)((info.file.size+1023) / 1024));
 		    if ((info.file.fields & GP_FILE_INFO_WIDTH) && +
 			    (info.file.fields & GP_FILE_INFO_HEIGHT))
-			printf(" %4dx%-4d", info.file.width, info.file.height);
+                printf(" %4dx%-4d", info.file.width, info.file.height);
 		    if (info.file.fields & GP_FILE_INFO_TYPE)
-			printf(" %s", info.file.type);
+                printf(" %s", info.file.type);
+		    if (info.file.fields & GP_FILE_INFO_MTIME)
+                printf(" %ld", info.file.mtime);
 		    putchar ('\n');
 		} else
 		    printf("#%-5i %s\n", x+1, filename);
 	}
 	x++;
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
 save_file_action (GPParams *p, const char *folder, const char *filename)
 {
-	return (save_file_to_file (p->camera, p->context, p->flags,
-				   folder, filename, GP_FILE_TYPE_NORMAL));
+	return save_file_to_file (p->camera, p->context, p->flags,
+				   folder, filename, GP_FILE_TYPE_NORMAL);
 }
 
 int
 save_exif_action (GPParams *p, const char *folder, const char *filename)
 {
-	return (save_file_to_file (p->camera, p->context, p->flags,
-				   folder, filename, GP_FILE_TYPE_EXIF));
+	return save_file_to_file (p->camera, p->context, p->flags,
+				   folder, filename, GP_FILE_TYPE_EXIF);
 }
 
 int
 save_meta_action (GPParams *p, const char *folder, const char *filename)
 {
-	return (save_file_to_file (p->camera, p->context, p->flags,
-				   folder, filename, GP_FILE_TYPE_METADATA));
+	return save_file_to_file (p->camera, p->context, p->flags,
+				   folder, filename, GP_FILE_TYPE_METADATA);
 }
 
 int
 save_thumbnail_action (GPParams *p, const char *folder, const char *filename)
 {
-	return (save_file_to_file (p->camera, p->context, p->flags,
-				   folder, filename, GP_FILE_TYPE_PREVIEW));
+	return save_file_to_file (p->camera, p->context, p->flags,
+				   folder, filename, GP_FILE_TYPE_PREVIEW);
 }
 
 int
 save_raw_action (GPParams *p, const char *folder, const char *filename)
 {
-	return (save_file_to_file (p->camera, p->context, p->flags,
-				   folder, filename, GP_FILE_TYPE_RAW));
+	return save_file_to_file (p->camera, p->context, p->flags,
+				   folder, filename, GP_FILE_TYPE_RAW);
 }
 
 int
 save_audio_action (GPParams *p, const char *folder, const char *filename)
 {
-	return (save_file_to_file (p->camera, p->context, p->flags,
-				   folder, filename, GP_FILE_TYPE_AUDIO));
+	return save_file_to_file (p->camera, p->context, p->flags,
+				   folder, filename, GP_FILE_TYPE_AUDIO);
 }
 
 int
@@ -430,9 +458,9 @@ save_all_audio_action (GPParams *p, const char *folder, const char *filename)
 	/* not every file has an associated audio file */
 	if (camera_file_exists(p->camera, p->context, folder, filename,
 			       GP_FILE_TYPE_AUDIO))
-		return (save_file_to_file (p->camera, p->context, p->flags,
+		return save_file_to_file (p->camera, p->context, p->flags,
 					   folder, filename,
-					   GP_FILE_TYPE_AUDIO));
+					   GP_FILE_TYPE_AUDIO);
 	return GP_OK;
 }
 
@@ -446,10 +474,10 @@ delete_file_action (GPParams *p, const char *folder, const char *filename)
 					     &info, p->context));
 		if (info.file.fields & GP_FILE_INFO_STATUS &&
 		    info.file.status == GP_FILE_STATUS_DOWNLOADED)
-			return (GP_OK);
+			return GP_OK;
 	}
-	return (gp_camera_file_delete (p->camera, folder, filename,
-				       p->context));
+	return gp_camera_file_delete (p->camera, folder, filename,
+				       p->context);
 }
 
 #ifdef HAVE_LIBEXIF
@@ -463,13 +491,9 @@ show_ifd (ExifContent *content)
                 e = content->entries[i];
                 printf ("%-20.20s", exif_tag_get_name (e->tag));
                 printf ("|");
-#ifdef HAVE_LIBEXIF_LOG
 		{char b[1024];
 		printf ("%-59.59s", exif_entry_get_value (e, b, sizeof (b)));
 		}
-#else
-                printf ("%-59.59s", exif_entry_get_value (e));
-#endif
                 printf ("\n");
         }
 }
@@ -484,7 +508,7 @@ print_hline (void)
         printf ("+");
         for (i = 0; i < 59; i++)
                 putchar ('-');
-        putchar ('\n'); 
+        putchar ('\n');
 }
 #endif
 
@@ -496,9 +520,7 @@ print_exif_action (GPParams *p, const char *folder, const char *filename)
         const char *data;
         unsigned long size;
         ExifData *ed;
-#ifdef HAVE_LIBEXIF_IFD
 	unsigned int i;
-#endif
 
         CR (gp_file_new (&file));
         CRU (gp_camera_file_get (p->camera, folder, filename,
@@ -508,7 +530,7 @@ print_exif_action (GPParams *p, const char *folder, const char *filename)
         gp_file_unref (file);
         if (!ed) {
                 gp_context_error (p->context, _("Could not parse EXIF data."));
-                return (GP_ERROR);
+                return GP_ERROR;
         }
 
         printf (_("EXIF tags:"));
@@ -519,22 +541,9 @@ print_exif_action (GPParams *p, const char *folder, const char *filename)
         printf ("%-59.59s", _("Value"));
         putchar ('\n');
         print_hline ();
-#ifdef HAVE_LIBEXIF_IFD
 	for (i = 0; i < EXIF_IFD_COUNT; i++)
 		if (ed->ifd[i])
 			show_ifd (ed->ifd[i]);
-#else
-        if (ed->ifd0)
-                show_ifd (ed->ifd0);
-        if (ed->ifd1)
-                show_ifd (ed->ifd1);
-        if (ed->ifd_exif)
-                show_ifd (ed->ifd_exif);
-        if (ed->ifd_gps)
-                show_ifd (ed->ifd_gps);
-        if (ed->ifd_interoperability)
-                show_ifd (ed->ifd_interoperability);
-#endif
         print_hline ();
         if (ed->size) {
                 printf (_("EXIF data contains a thumbnail (%i bytes)."),
@@ -544,11 +553,11 @@ print_exif_action (GPParams *p, const char *folder, const char *filename)
 
         exif_data_unref (ed);
 
-        return (GP_OK);
+        return GP_OK;
 #else
 	gp_context_error (p->context, _("gphoto2 has been compiled without "
 		"EXIF support."));
-	return (GP_ERROR_NOT_SUPPORTED);
+	return GP_ERROR_NOT_SUPPORTED;
 #endif
 }
 
@@ -560,7 +569,7 @@ list_cameras_action (GPParams *p)
 
 	r = gp_abilities_list_count (gp_params_abilities_list(p));
 	if (r < 0)
-		return (r);
+		return r;
 	if (p->flags & FLAGS_QUIET)
 		printf ("%i\n", r);
 	else {
@@ -591,7 +600,7 @@ list_cameras_action (GPParams *p)
 			}
 	}
 
-	return (r);
+	return r;
 }
 
 void
@@ -645,7 +654,7 @@ list_ports_action (GPParams *p)
 		gp_port_info_get_path (info, &xpath);
 		printf ("%-32s %-32s\n", xpath, xname);
 	}
-	return (result);
+	return result;
 
 }
 
@@ -727,13 +736,13 @@ action_camera_show_abilities (GPParams *p)
         	(a.folder_operations & GP_FOLDER_OPERATION_DELETE_ALL) ?
                 					_("yes"):_("no"));
 	printf (_("File preview (thumbnail) support : %s\n"),
-		(a.file_operations & GP_FILE_OPERATION_PREVIEW) ? 
+		(a.file_operations & GP_FILE_OPERATION_PREVIEW) ?
 							_("yes"):_("no"));
 	printf (_("File upload support              : %s\n"),
 		(a.folder_operations & GP_FOLDER_OPERATION_PUT_FILE) ?
 							_("yes"):_("no"));
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -765,6 +774,9 @@ action_camera_set_port (GPParams *params, const char *port)
 			strncat (verified_port, port,
 				 sizeof (verified_port)
 				 	- strlen (verified_port) - 1);
+		} else {
+			gp_log (GP_LOG_ERROR, "main", "Could not guess type of port for name '%s'.", port);
+			return GP_ERROR_UNKNOWN_PORT;
 		}
 		gp_log (GP_LOG_DEBUG, "main", "Guessed port name. Using port "
 			"'%s' from now on.", verified_port);
@@ -791,19 +803,21 @@ action_camera_set_port (GPParams *params, const char *port)
 	default:
 		break;
 	}
+	if (p < GP_OK)
+		return p;
 
 	/* Get info about our port. */
 	r = gp_port_info_list_get_info (params->portinfo_list, p, &info);
 	if (r < 0)
-		return (r);
+		return r;
 
 	/* Set the port of our camera. */
 	r = gp_camera_set_port_info (params->camera, info);
 	if (r < 0)
-		return (r);
+		return r;
 	gp_port_info_get_path (info, &path);
 	gp_setting_set ("gphoto2", "port", path);
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -812,11 +826,11 @@ action_camera_about (GPParams *params)
 	CameraText text;
 
 	CR (gp_camera_get_about (params->camera, &text, params->context));
-	
+
 	printf (_("About the camera driver:"));
 	printf ("\n%s\n", _(text.text));
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -829,7 +843,7 @@ action_camera_summary (GPParams *params)
 	printf (_("Camera summary:"));
 	printf ("\n%s\n", _(text.text));
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -842,7 +856,7 @@ action_camera_manual (GPParams *params)
 	printf (_("Camera manual:"));
 	printf ("\n%s\n", _(text.text));
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -860,7 +874,7 @@ action_camera_set_speed (GPParams *p, unsigned int speed)
 					   "serial ports."));
 			fputc ('\n', stderr);
 		}
-		return (GP_ERROR_BAD_PARAMETERS);
+		return GP_ERROR_BAD_PARAMETERS;
 	}
 	/* Set the speed. */
 	return gp_camera_set_port_speed (p->camera, speed);
@@ -877,7 +891,7 @@ action_camera_set_model (GPParams *p, const char *model)
 	CR (gp_camera_set_abilities (p->camera, a));
 	gp_setting_set ("gphoto2", "model", a.model);
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int
@@ -904,16 +918,9 @@ int
 print_version_action (GPParams __unused__ *p)
 {
 	int n;
-	const char *port_message =
-#ifdef OS2
-			_("OS/2 port by Bart van Leeuwen\n");
-#else
-			"";
-#endif
 	printf (_("gphoto2 %s\n"
 		  "\n"
 		  "Copyright (c) 2000-%d Marcus Meissner and others\n"
-		  "%s"
 		  "\n"
 		  "gphoto2 comes with NO WARRANTY, to the extent permitted by law. You may\n"
 		  "redistribute copies of gphoto2 under the terms of the GNU General Public\n"
@@ -921,8 +928,7 @@ print_version_action (GPParams __unused__ *p)
 		  "\n"
 		  "This version of gphoto2 is using the following software versions and options:\n"),
 		VERSION,
-		2021, /* year of release! */
-		port_message
+		2021 /* year of release! */
 		);
 
 	for (n = 0; module_versions[n].name != NULL; n++) {
@@ -945,7 +951,7 @@ print_version_action (GPParams __unused__ *p)
 	  putchar ('\n');
 	}
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 static int
@@ -995,7 +1001,7 @@ _action_camera_capture_preview (GPParams *p, int viewasciiart)
 		gp_file_unref (file);
 		if (r < 0) {
 			unlink (tmpname);
-			return (r);
+			return r;
 		}
 	}
 	return GP_OK;
@@ -1095,7 +1101,7 @@ action_camera_capture_movie (GPParams *p, const char *arg)
 }
 
 
-/* 
+/*
  * arg can be:
  * events as number			e.g.: 1000
  * frames as number with suffix f 	e.g.: 100f
@@ -1125,17 +1131,17 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 		printf ( _("Waiting for events from camera. Press Ctrl-C to abort.\n"));
 	} else {
 		int x;
-		if ((arg[strlen(arg)-1]=='f') && sscanf(arg,"%df", &x)) { /* exact nr of frames */ 
+		if ((arg[strlen(arg)-1]=='f') && sscanf(arg,"%df", &x)) { /* exact nr of frames */
 			wp.type			= WAIT_FRAMES;
 			wp.u.frames		= x;
 			printf ( _("Waiting for %d frames from the camera. Press Ctrl-C to abort.\n"), x);
 		} else
-		if ((strlen(arg)>2) && (!strcmp(&arg[strlen(arg)-2],"ms")) && sscanf(arg,"%dms",&x)) { /* exact milliseconds */ 
+		if ((strlen(arg)>2) && (!strcmp(&arg[strlen(arg)-2],"ms")) && sscanf(arg,"%dms",&x)) { /* exact milliseconds */
 			wp.type			= WAIT_TIME;
 			wp.u.milliseconds	= x;
 			printf ( _("Waiting for %d milliseconds for events from camera. Press Ctrl-C to abort.\n"), x);
 		} else
-		if ((wp.type != WAIT_TIME) && (arg[strlen(arg)-1]=='s') && sscanf(arg,"%ds", &x)) { /* exact seconds */ 
+		if ((wp.type != WAIT_TIME) && (arg[strlen(arg)-1]=='s') && sscanf(arg,"%ds", &x)) { /* exact seconds */
 			wp.type			= WAIT_TIME;
 			wp.u.milliseconds	= x*1000;
 			printf ( _("Waiting for %d seconds for events from camera. Press Ctrl-C to abort.\n"), x);
@@ -1144,7 +1150,7 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 			printf ( _("Waiting for %d events from camera. Press Ctrl-C to abort.\n"), wp.u.events);
 		} else {
 			wp.type = WAIT_STRING;
-			wp.u.str = arg;
+			wp.u.str = (char*)arg;
 			printf ( _("Waiting for '%s' event from camera. Press Ctrl-C to abort.\n"), wp.u.str);
 		}
 	}
@@ -1157,6 +1163,19 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 
 		if (glob_cancel) break;
 
+		if (capture_now) {
+			capture_now = 0;
+			data = malloc(sizeof(CameraFilePath));
+			printf(_("SIGUSR1 signal received, triggering capture!\n"));
+			ret = gp_camera_capture (p->camera, GP_CAPTURE_IMAGE, (CameraFilePath*)data, p->context);
+			if (ret == GP_OK) {
+				event = GP_EVENT_FILE_ADDED;
+				goto afterevent;
+			} else {
+				free (data);
+				data = NULL;
+			}
+		}
 		if (end_next) {
 			printf(_("SIGUSR2 signal received, stopping wait!\n"));
 			end_next = 0;
@@ -1188,6 +1207,7 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 		ret = gp_camera_wait_for_event (p->camera, leftoverms, &event, &data, p->context);
 		if (ret != GP_OK)
 			return ret;
+afterevent:
 		events++;
 		switch (event) {
 		case GP_EVENT_UNKNOWN:
@@ -1224,7 +1244,7 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 
 			if (	(downloadtype == DT_NO_DOWNLOAD)	||
 				(	(p->flags & FLAGS_KEEP_RAW) &&
-				 	( !strstr(fn->name,".jpg") && !strstr(fn->name,".JPG")) 
+				 	( !strstr(fn->name,".jpg") && !strstr(fn->name,".JPG"))
 				)
 			) {
 				printf("FILEADDED %s %s\n",fn->name, fn->folder);
@@ -1240,7 +1260,7 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 				ret = set_folder_action(p, fn->folder);
 				if (ret != GP_OK) {
 					cli_error_print(_("Could not set folder."));
-					return (ret);
+					return ret;
 				}
 			}
 			ret = get_file_common (fn->name, GP_FILE_TYPE_NORMAL);
@@ -1254,7 +1274,7 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 					*/
 					cli_error_print ( _("Buggy libcanon.so?"));
 				}
-				return (ret);
+				return ret;
 			}
 
 			if (!(p->flags & FLAGS_KEEP)) {
@@ -1421,7 +1441,7 @@ override_usbids_action (GPParams *p, int usb_vendor, int usb_product,
 	gp_abilities_list_free (p->_abilities_list);
 	p->_abilities_list = al;
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 /* time zero for debug log time stamps */
@@ -1451,7 +1471,7 @@ debug_action (GPParams *p, const char *debug_loglevel, const char *debug_logfile
 	/* make sure we're only executed once */
 	static int debug_flag = 0;
 	if (debug_flag != 0)
-		return(GP_OK);
+		return GP_OK;
 	debug_flag = 1;
 
 	if (debug_loglevel && !strcmp(debug_loglevel, "error"))
@@ -1505,18 +1525,18 @@ debug_action (GPParams *p, const char *debug_loglevel, const char *debug_logfile
 		if (camlibs) {
 			gp_log (GP_LOG_DEBUG, "main", "CAMLIBS = '%s'", camlibs);
 		} else {
-			gp_log (GP_LOG_DEBUG, "main", 
+			gp_log (GP_LOG_DEBUG, "main",
 				"CAMLIBS env var not set, using compile-time default instead");
 		}
 		if (iolibs) {
 			gp_log (GP_LOG_DEBUG, "main", "IOLIBS = '%s'", iolibs);
 		} else {
-			gp_log (GP_LOG_DEBUG, "main", 
+			gp_log (GP_LOG_DEBUG, "main",
 				"IOLIBS env var not set, using compile-time default instead");
 		}
 	}
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 static void
@@ -1569,7 +1589,7 @@ list_all_config_action (GPParams *p) {
 	if (ret != GP_OK) return ret;
 	display_widgets (p, rootconfig, "", 1);
 	gp_widget_free (rootconfig);
-	return (GP_OK);
+	return GP_OK;
 }
 int
 list_config_action (GPParams *p) {
@@ -1580,7 +1600,7 @@ list_config_action (GPParams *p) {
 	if (ret != GP_OK) return ret;
 	display_widgets (p, rootconfig, "", 0);
 	gp_widget_free (rootconfig);
-	return (GP_OK);
+	return GP_OK;
 }
 
 static int
@@ -1597,7 +1617,7 @@ _find_widget_by_name (GPParams *p, const char *name, CameraWidget **child, Camer
 	ret = gp_camera_get_config (p->camera, rootconfig, p->context);
 	if (ret != GP_OK) return ret;
 	ret = gp_widget_get_child_by_name (*rootconfig, name, child);
-	if (ret != GP_OK) 
+	if (ret != GP_OK)
 		ret = gp_widget_get_child_by_label (*rootconfig, name, child);
 	if (ret != GP_OK) {
 		char		*part, *s, *newname;
@@ -1923,7 +1943,7 @@ set_config_action (GPParams *p, const char *name, const char *value) {
 		if (i != cnt)
 			break;
 
-		/* make sure we parse just 1 integer, and there is nothing more. 
+		/* make sure we parse just 1 integer, and there is nothing more.
 		 * sscanf just does not provide this, we need strtol.
 		 */
 		i = strtol (value, &endptr, 10);
@@ -1963,7 +1983,7 @@ set_config_action (GPParams *p, const char *name, const char *value) {
 			gp_context_error (p->context, _("Failed to set new configuration value %s for configuration entry %s."), value, name);
 	}
 	gp_widget_free (rootconfig);
-	return (ret);
+	return ret;
 }
 
 int
@@ -2017,7 +2037,7 @@ set_config_index_action (GPParams *p, const char *name, const char *value) {
 	case GP_WIDGET_TOGGLE:
 	case GP_WIDGET_TEXT:
 	case GP_WIDGET_RANGE:
-	case GP_WIDGET_DATE: 
+	case GP_WIDGET_DATE:
 	case GP_WIDGET_WINDOW:
 	case GP_WIDGET_SECTION:
 	case GP_WIDGET_BUTTON:
@@ -2034,7 +2054,7 @@ set_config_index_action (GPParams *p, const char *name, const char *value) {
 			gp_context_error (p->context, _("Failed to set new configuration value %s for configuration entry %s."), value, name);
 	}
 	gp_widget_free (rootconfig);
-	return (ret);
+	return ret;
 }
 
 
@@ -2179,7 +2199,7 @@ set_config_value_action (GPParams *p, const char *name, const char *value) {
 			gp_context_error (p->context, _("Failed to set new configuration value %s for configuration entry %s."), value, name);
 	}
 	gp_widget_free (rootconfig);
-	return (ret);
+	return ret;
 }
 
 
