@@ -7,10 +7,10 @@
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -19,6 +19,7 @@
  */
 
 #define _DARWIN_C_SOURCE
+#define _XOPEN_SOURCE 500
 
 #include "config.h"
 #if defined (HAVE_SIGNAL_H)
@@ -52,15 +53,7 @@
 #include <errno.h>
 #include <sys/time.h>
 
-#ifdef HAVE_POPT
-#  include <popt.h>
-/* POPT_TABLEEND is only defined from popt 1.6.1 */
-# ifndef POPT_TABLEEND
-#  define POPT_TABLEEND { NULL, '\0', 0, 0, 0, NULL, NULL }
-# endif
-#else
-# error gphoto2 now REQUIRES the popt library!
-#endif
+#include <popt.h>
 
 #ifdef HAVE_RL
 #  include <readline/readline.h>
@@ -119,9 +112,9 @@ static size_t
 strncpy_lower(char *dst, const char *src, size_t count)
 {
 	unsigned int i;
-	if ((dst == NULL) || (src == NULL) 
-	    || (((unsigned long)count)>= 0x7fff)) { 
-		return -1; 
+	if ((dst == NULL) || (src == NULL)
+	    || (((unsigned long)count)>= 0x7fff)) {
+		return -1;
 	}
 	for (i=0; (i<count) && (src[i] != '\0'); i++) {
 		dst[i] = (char) tolower((int)src[i]);
@@ -157,10 +150,9 @@ get_path_for_file (const char *folder, const char *name, CameraFileType type, Ca
 	time_t t = 0;
 	struct tm *tm;
 	int hour12;
-	static int filenr = 1;
 
 	if (!path)
-		return (GP_ERROR_BAD_PARAMETERS);
+		return GP_ERROR_BAD_PARAMETERS;
 
 	*path = NULL;
 	if (file) {
@@ -177,7 +169,7 @@ get_path_for_file (const char *folder, const char *name, CameraFileType type, Ca
 	}
 
 	/*
-	 * If the user didn't specify a filename, use the original name 
+	 * If the user didn't specify a filename, use the original name
 	 * (and prefix).
 	 */
 	if (!gp_params.filename || !strcmp (gp_params.filename, "")) {
@@ -217,7 +209,7 @@ get_path_for_file (const char *folder, const char *name, CameraFileType type, Ca
 				long int _prec;
 				_prec = strtol(&gp_params.filename[i],
 					       &cp, 10);
-				if (_prec < 1) 
+				if (_prec < 1)
 					precision = 1;
 				else if (_prec > 20)
 					precision = 20;
@@ -253,12 +245,12 @@ get_path_for_file (const char *folder, const char *name, CameraFileType type, Ca
 					strcpy(padfmt, "%!.*i");
 					padfmt[1] = padding;
 					snprintf (b, sizeof (b), padfmt,
-						  precision, filenr);
+						  precision, gp_params.filenr);
 				} else {
 					snprintf (b, sizeof (b), "%i",
-						  filenr);
+						  gp_params.filenr);
 				}
-				filenr++;
+				gp_params.filenr++;
 				break;
 
 			case 'C':
@@ -415,9 +407,9 @@ save_camera_file_to_file (
 			if ((c[0]=='y') || (c[0]=='Y'))
 				break;
 
-			do { 
+			do {
 				printf (_("Specify new filename? [y|n] "));
-				fflush (stdout); 
+				fflush (stdout);
 				if (NULL == fgets (c, sizeof (c) - 1, stdin))
 					return GP_ERROR;
 			} while ((c[0]!='y')&&(c[0]!='Y')&&
@@ -1311,6 +1303,7 @@ typedef enum {
 	ARG_DELETE_ALL_FILES,
 	ARG_DELETE_FILE,
 	ARG_FILENAME,
+	ARG_FILENUMBER,
 	ARG_FOLDER,
 	ARG_FORCE_OVERWRITE,
 	ARG_GET_ALL_AUDIO_DATA,
@@ -1353,6 +1346,7 @@ typedef enum {
 	ARG_SHELL,
 	ARG_SHOW_EXIF,
 	ARG_SHOW_INFO,
+	ARG_PARSABLE,
 	ARG_SKIP_EXISTING,
 	ARG_SPEED,
 	ARG_STDOUT,
@@ -1401,7 +1395,7 @@ struct _CallbackParams {
  */
 
 static void
-cb_arg_query (poptContext __unused__ ctx, 
+cb_arg_query (poptContext __unused__ ctx,
 	      enum poptCallbackReason __unused__ reason,
 	      const struct poptOption *opt, const char __unused__ *arg,
 	      CallbackParams *params)
@@ -1416,7 +1410,7 @@ cb_arg_query (poptContext __unused__ ctx,
  */
 
 static void
-cb_arg_preinit (poptContext __unused__ ctx, 
+cb_arg_preinit (poptContext __unused__ ctx,
 		enum poptCallbackReason __unused__ reason,
 		const struct poptOption *opt, const char *arg,
 		CallbackParams *params)
@@ -1453,7 +1447,7 @@ cb_arg_preinit (poptContext __unused__ ctx,
  */
 
 static void
-cb_arg_init (poptContext __unused__ ctx, 
+cb_arg_init (poptContext __unused__ ctx,
 	     enum poptCallbackReason __unused__ reason,
 	     const struct poptOption *opt, const char *arg,
 	     CallbackParams *params)
@@ -1463,6 +1457,10 @@ cb_arg_init (poptContext __unused__ ctx,
 	case ARG_FILENAME:
 		params->p.r = set_filename_action (&gp_params, arg);
 		break;
+	case ARG_FILENUMBER:
+		gp_params.filenr = atoi (arg);
+		params->p.r = GP_OK;
+		break;
 	case ARG_FOLDER:
 		params->p.r = set_folder_action (&gp_params, arg);
 		break;
@@ -1514,6 +1512,11 @@ cb_arg_init (poptContext __unused__ ctx,
 		gp_params.flags |= FLAGS_QUIET;
 		break;
 
+	case ARG_PARSABLE:
+		gp_params.flags |= FLAGS_QUIET;
+		gp_params.flags |= FLAGS_PARSABLE;
+		break;
+
 	case ARG_RESET_INTERVAL:
 		gp_params.flags |= FLAGS_RESET_CAPTURE_INTERVAL;
 		break;
@@ -1541,7 +1544,7 @@ cb_arg_init (poptContext __unused__ ctx,
 		gp_params.flags |= FLAGS_QUIET | FLAGS_STDOUT;
 		break;
 	case ARG_STDOUT_SIZE:
-		gp_params.flags |= FLAGS_QUIET | FLAGS_STDOUT 
+		gp_params.flags |= FLAGS_QUIET | FLAGS_STDOUT
 			| FLAGS_STDOUT_SIZE;
 		break;
 
@@ -1567,7 +1570,7 @@ cb_arg_init (poptContext __unused__ ctx,
  */
 
 static void
-cb_arg_run (poptContext __unused__ ctx, 
+cb_arg_run (poptContext __unused__ ctx,
 	    enum poptCallbackReason __unused__ reason,
 	    const struct poptOption *opt, const char *arg,
 	    CallbackParams *params)
@@ -1737,12 +1740,12 @@ cb_arg_run (poptContext __unused__ ctx,
 		/* Did the user specify a file or a range? */
 		if (strchr (arg, '.')) {
 			dissolve_filename (gp_params.folder, arg, &newfolder, &newfilename);
-			params->p.r = print_exif_action (&gp_params, newfolder, newfilename); 
+			params->p.r = print_exif_action (&gp_params, newfolder, newfilename);
 			free (newfolder); free (newfilename);
-			break; 
-		} 
-		params->p.r = for_each_file_in_range (&gp_params, 
-						      print_exif_action, arg); 
+			break;
+		}
+		params->p.r = for_each_file_in_range (&gp_params,
+						      print_exif_action, arg);
 		break;
 	case ARG_SHOW_INFO:
 		/* Did the user specify a file or a range? */
@@ -1844,7 +1847,7 @@ cb_arg_run (poptContext __unused__ ctx,
  */
 
 static void
-cb_arg (poptContext __unused__ ctx, 
+cb_arg (poptContext __unused__ ctx,
 	enum poptCallbackReason __unused__ reason,
 	const struct poptOption *opt, const char *arg,
 	void *data)
@@ -1870,7 +1873,7 @@ cb_arg (poptContext __unused__ ctx,
 		cb_arg_run (ctx, reason, opt, arg, params);
 		break;
 	}
-};
+}
 
 
 static void
@@ -1990,6 +1993,8 @@ main (int argc, char **argv, char **envp)
 		 N_("Name of file to write debug info to"), N_("FILENAME")},
 		{"quiet", 'q', POPT_ARG_NONE, NULL, ARG_QUIET,
 		 N_("Quiet output (default=verbose)"), NULL},
+		{"parsable", '\0', POPT_ARG_NONE, NULL, ARG_PARSABLE,
+		 N_("Simple parsable output (implies quiet)"), NULL},
 		{"hook-script", '\0', POPT_ARG_STRING, NULL, ARG_HOOK_SCRIPT,
 		 N_("Hook script to call after downloads, captures, etc."),
 		 N_("FILENAME")},
@@ -2050,9 +2055,9 @@ main (int argc, char **argv, char **envp)
 		{"no-keep", '\0', POPT_ARG_NONE, NULL, ARG_NO_KEEP,
 		 N_("Remove images from camera after capturing"), NULL},
 		{"wait-event", '\0', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, NULL, ARG_WAIT_EVENT,
-		 N_("Wait for event(s) from camera"), N_("COUNT, SECONDS, MILLISECONDS or MATCHSTRING")},
+		 N_("Wait for event(s) from camera"), N_("EVENT")},
 		{"wait-event-and-download", '\0', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, NULL,
-		 ARG_CAPTURE_TETHERED, N_("Wait for event(s) from the camera and download new images"), N_("COUNT, SECONDS, MILLISECONDS or MATCHSTRING")},
+		 ARG_CAPTURE_TETHERED, N_("Wait for event(s) from the camera and download new images"), N_("EVENT")},
 		{"capture-preview", '\0', POPT_ARG_NONE, NULL,
 		 ARG_CAPTURE_PREVIEW,
 		 N_("Capture a quick preview"), NULL},
@@ -2078,7 +2083,7 @@ main (int argc, char **argv, char **envp)
 		{"capture-sound", '\0', POPT_ARG_NONE, NULL,
 		 ARG_CAPTURE_SOUND, N_("Capture an audio clip"), NULL},
 		{"capture-tethered", '\0', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, NULL,
-		 ARG_CAPTURE_TETHERED, N_("Wait for shutter release on the camera and download"), N_("COUNT, SECONDS, MILLISECONDS or MATCHSTRING")},
+		 ARG_CAPTURE_TETHERED, N_("Wait for shutter release on the camera and download"), N_("EVENT")},
 		POPT_TABLEEND
 	};
 	const struct poptOption fileOptions[] = {
@@ -2128,6 +2133,8 @@ main (int argc, char **argv, char **envp)
 		 N_("Upload a file to camera"), N_("FILENAME")},
 		{"filename", '\0', POPT_ARG_STRING, NULL, ARG_FILENAME,
 		 N_("Specify a filename or filename pattern"), N_("FILENAME_PATTERN")},
+		{"filenumber", '\0', POPT_ARG_INT, NULL, ARG_FILENUMBER,
+		 N_("Specify the number a filename %%n will starts with (default 1)"), N_("NUMBER")},
 		{"folder", 'f', POPT_ARG_STRING, NULL, ARG_FOLDER,
 		 N_("Specify camera folder (default=\"/\")"), N_("FOLDER")},
 		{"recurse", 'R', POPT_ARG_NONE, NULL, ARG_RECURSE,
@@ -2225,7 +2232,7 @@ main (int argc, char **argv, char **envp)
 	}
 
 	/*
-	 * Do we need debugging output? While we are at it, scan the 
+	 * Do we need debugging output? While we are at it, scan the
 	 * options for bad ones.
 	 */
 	poptResetContext (ctx);
@@ -2238,6 +2245,8 @@ main (int argc, char **argv, char **envp)
 	}
 	if (help_option_given) {
 		poptPrintHelp(ctx, stdout, 0);
+		fprintf(stdout, "\n%s",
+			_("EVENT can be either COUNT, SECONDS, MILLISECONDS, or MATCHSTRING.\n"));
 		gp_params_exit (&gp_params);
                 poptFreeContext(ctx);
 		return 0;
@@ -2265,10 +2274,13 @@ main (int argc, char **argv, char **envp)
 	cb_params.type = CALLBACK_PARAMS_TYPE_PREINITIALIZE;
 	cb_params.p.r = GP_OK;
 	poptResetContext (ctx);
-	while ((cb_params.p.r >= 0) && (poptGetNextOpt (ctx) >= 0));
+	while ((cb_params.p.r >= GP_OK) && (poptGetNextOpt (ctx) >= 0));
+
+	CR_MAIN (cb_params.p.r);
+
 	cb_params.type = CALLBACK_PARAMS_TYPE_INITIALIZE;
 	poptResetContext (ctx);
-	while ((cb_params.p.r >= 0) && (poptGetNextOpt (ctx) >= 0));
+	while ((cb_params.p.r >= GP_OK) && (poptGetNextOpt (ctx) >= 0));
 	/* Load default values for --filename and --hook-script if not
 	 * explicitely specified
 	 */
@@ -2362,7 +2374,7 @@ main (int argc, char **argv, char **envp)
 
 		_get_portinfo_list(&gp_params);
 		CR_MAIN (gp_list_new (&list)); /* no freeing below */
-		CR_MAIN (gp_abilities_list_detect (gp_params_abilities_list(&gp_params), 
+		CR_MAIN (gp_abilities_list_detect (gp_params_abilities_list(&gp_params),
 						   gp_params.portinfo_list,
 						   list, gp_params.context));
 		CR_MAIN (count = gp_list_count (list));
@@ -2375,7 +2387,7 @@ main (int argc, char **argv, char **envp)
 				int m;
 
 				CR_MAIN (m = gp_abilities_list_lookup_model (
-						 gp_params_abilities_list(&gp_params), 
+						 gp_params_abilities_list(&gp_params),
 						 model));
 				CR_MAIN (gp_abilities_list_get_abilities (
 						 gp_params_abilities_list(&gp_params),
@@ -2392,6 +2404,15 @@ main (int argc, char **argv, char **envp)
 			if (use_auto) {
 				CR_MAIN (action_camera_set_model (&gp_params, model));
 			}
+			if (type == GP_PORT_USB) {
+				char *xpath;
+
+				gp_port_info_get_path (info, &xpath);
+				if (strcmp(xpath, "usb:") && strcmp(xpath, path)) {
+					fprintf (stderr, _("Port %s not found\n"), xpath );
+					CR_MAIN (GP_ERROR_UNKNOWN_PORT);
+				}
+			}
 			CR_MAIN (action_camera_set_port (&gp_params, path));
 
                 } else if (!count) {
@@ -2436,6 +2457,10 @@ main (int argc, char **argv, char **envp)
 				}
 				if (i != count)
 					use_auto = 0;
+				if ((type == GP_PORT_USB) && (i == count) && (strcmp(xpath, "usb:"))) {
+					fprintf (stderr, _("Port %s not found\n"), xpath );
+					CR_MAIN (GP_ERROR_UNKNOWN_PORT);
+				}
 			}
 			/* If --camera override, search the model with the same USB ID. */
 			if (use_auto && a.model[0]) {
@@ -2571,7 +2596,7 @@ main (int argc, char **argv, char **envp)
 
 	gp_params_exit (&gp_params);
         poptFreeContext(ctx);
-        return (EXIT_SUCCESS);
+        return EXIT_SUCCESS;
 }
 
 
